<?php

namespace App\Controller;

use App\Entity\CameraStream;
use App\Form\CameraStreamType;
use App\Repository\CameraStreamRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/admin/camera/stream")
 */
class AdminCameraStreamController extends AbstractController
{
    /**
     * @Route("/", name="admin_camera_stream_index", methods={"GET"})
     */
    public function index(CameraStreamRepository $cameraStreamRepository): Response
    {
        return $this->render('admin_camera_stream/index.html.twig', [
            'camera_streams' => $cameraStreamRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new", name="admin_camera_stream_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $cameraStream = new CameraStream();
        $form = $this->createForm(CameraStreamType::class, $cameraStream);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($cameraStream);
            $entityManager->flush();

            return $this->redirectToRoute('admin_camera_stream_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('admin_camera_stream/new.html.twig', [
            'camera_stream' => $cameraStream,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="admin_camera_stream_show", methods={"GET"})
     */
    public function show(CameraStream $cameraStream): Response
    {
        return $this->render('admin_camera_stream/show.html.twig', [
            'camera_stream' => $cameraStream,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="admin_camera_stream_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, CameraStream $cameraStream): Response
    {
        $form = $this->createForm(CameraStreamType::class, $cameraStream);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('admin_camera_stream_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('admin_camera_stream/edit.html.twig', [
            'camera_stream' => $cameraStream,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="admin_camera_stream_delete", methods={"POST"})
     */
    public function delete(Request $request, CameraStream $cameraStream): Response
    {
        if ($this->isCsrfTokenValid('delete'.$cameraStream->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($cameraStream);
            $entityManager->flush();
        }

        return $this->redirectToRoute('admin_camera_stream_index', [], Response::HTTP_SEE_OTHER);
    }
}
