<?php

namespace App\Controller;

use App\Entity\Invoice;
use App\Entity\Payment;
use App\Form\PaymentType;
use App\Repository\PaymentRepository;
use App\Service\PaymentService;
use App\Service\UrlBuilderService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/admin/payment")
 */
class AdminPaymentController extends AbstractController
{
    /**
     * @Route("/", name="admin_payment_index", methods={"GET"})
     */
    public function index(PaymentRepository $paymentRepository): Response
    {
        return $this->render('admin_payment/index.html.twig', [
            'payments' => $paymentRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new/{id}", name="admin_payment_new", methods={"GET","POST"})
     */
    public function new(Request $request, Invoice $invoice, PaymentService $paymentService, UrlBuilderService $urlBuilderService): Response
    {
        $payment = new Payment();
        $payment->setInvoice($invoice);
        $payment->setCreatedAt(new \DateTimeImmutable());
        $payment->setAmount($invoice->getTotalAmount());

        $form = $this->createForm(PaymentType::class, $payment);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $stripeSesionId = $paymentService->create($payment->getAmount());
            $payment->setStripeSessionId($stripeSesionId);
            $url = $urlBuilderService->build('/payment/redirect/' . $stripeSesionId);
            $payment->setPaymentLink($url);
            $entityManager->persist($payment);
            $entityManager->flush();
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('admin_payment_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('admin_payment/new.html.twig', [
            'payment' => $payment,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="admin_payment_show", methods={"GET"})
     */
    public function show(Payment $payment): Response
    {
        return $this->render('admin_payment/show.html.twig', [
            'payment' => $payment,
        ]);
    }

    /**
     * @Route("/{id}", name="admin_payment_delete", methods={"POST"})
     */
    public function delete(Request $request, Payment $payment): Response
    {
        if ($this->isCsrfTokenValid('delete'.$payment->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($payment);
            $entityManager->flush();
        }

        return $this->redirectToRoute('admin_payment_index', [], Response::HTTP_SEE_OTHER);
    }
}
