<?php

namespace App\Controller;

use App\Entity\Printing;
use App\Entity\Purchase;
use App\Form\PrintingAdminType;
use App\Repository\PrintingRepository;
use App\Service\FileUploader;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/admin/printing")
 */
class AdminPrintingController extends AbstractController
{
    /**
     * @Route("/new/{id}", name="admin_printing_new", methods={"GET","POST"})
     */
    public function new(Request $request, Purchase $purchase, FileUploader $fileUploader): Response
    {
        $printing = new Printing();
        $form = $this->createForm(PrintingAdminType::class, $printing);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $modelFile = $form->get('filepath')->getData();
            if ($modelFile) {
                $modelFileName = $fileUploader->upload($modelFile);
                $printing->setFilepath($modelFileName);
            }
            $purchase->addPrinting($printing);
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($printing);
            $entityManager->flush();

            return $this->redirectToRoute('admin_purchase_show', [
                'id' => $purchase->getId()
            ]);
        }

        return $this->render('admin_printing/new.html.twig', [
            'printing' => $printing,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="admin_printing_show", methods={"GET"})
     */
    public function show(Printing $printing): Response
    {
        return $this->render('admin_printing/show.html.twig', [
            'printing' => $printing,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="admin_printing_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, Printing $printing, FileUploader $fileUploader): Response
    {
        $form = $this->createForm(PrintingAdminType::class, $printing);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $modelFile = $form->get('filepath')->getData();
            if ($modelFile) {
                $modelFileName = $fileUploader->upload($modelFile);
                $printing->setFilepath($modelFileName);
            }
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('admin_printing_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('admin_printing/edit.html.twig', [
            'printing' => $printing,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="admin_printing_delete", methods={"POST"})
     */
    public function delete(Request $request, Printing $printing): Response
    {
        if ($this->isCsrfTokenValid('delete'.$printing->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($printing);
            $entityManager->flush();
        }

        return $this->redirectToRoute('admin_printing_index', [], Response::HTTP_SEE_OTHER);
    }
}
