<?php

namespace App\Controller;

use App\Entity\Purchase;
use App\Form\PurchaseType;
use App\Repository\PurchaseRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/admin/purchase")
 */
class AdminPurchaseController extends AbstractController
{
    /**
     * @Route("/", name="admin_purchase_index", methods={"GET"})
     */
    public function index(PurchaseRepository $purchaseRepository): Response
    {
        return $this->render('admin_purchase/index.html.twig', [
            'purchases' => $purchaseRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new", name="admin_purchase_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $purchase = new Purchase();
        $form = $this->createForm(PurchaseType::class, $purchase);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($purchase);
            $entityManager->flush();

            return $this->redirectToRoute('admin_purchase_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('admin_purchase/new.html.twig', [
            'purchase' => $purchase,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="admin_purchase_show", methods={"GET"})
     */
    public function show(Purchase $purchase): Response
    {
        $status = $purchase->getStatus();
        $nextStatus = 'waiting_validation';
        switch ($status) {
            case 'waiting_validation' : 
                $nextStatus = 'confirmed';
                break;
            case 'confirmed' : 
                $nextStatus = 'printing';
                break;
            case 'printing' : 
                $nextStatus = 'ready';
                break;
            case 'ready' : 
                $nextStatus = 'delivered';
                break;
            case 'delivered' : 
                $nextStatus = null;
                break;
        }

        return $this->render('admin_purchase/show.html.twig', [
            'purchase' => $purchase,
            'nextStatus' => $nextStatus
        ]);
    }

    /**
     * @Route("/{id}/status/{key}", name="admin_purchase_change_status", methods={"GET"})
     */
    public function changeStatus(Purchase $purchase, string $key): Response
    {
        $purchase->setStatus($key);
        $this->getDoctrine()->getManager()->flush();
        return $this->redirectToRoute('admin_purchase_show', [
            'id' => $purchase->getId()
        ]);
    }

    /**
     * @Route("/{id}", name="admin_purchase_delete", methods={"POST"})
     */
    public function delete(Request $request, Purchase $purchase): Response
    {
        if ($this->isCsrfTokenValid('delete'.$purchase->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($purchase);
            $entityManager->flush();
        }

        return $this->redirectToRoute('admin_purchase_index', [], Response::HTTP_SEE_OTHER);
    }
}
