<?php

namespace App\Controller;

use App\Entity\Printing;
use App\Entity\Purchase;
use App\Form\PrintingType;
use App\Repository\PrintingRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use App\Service\FileUploader;

/**
 * @Route("/printing")
 */
class PrintingController extends AbstractController
{

    /**
     * @Route("/order/{id}/new", name="printing_new", methods={"GET","POST"})
     */
    public function new(Purchase $purchase, Request $request, FileUploader $fileUploader): Response
    {
        $printing = new Printing();
        $form = $this->createForm(PrintingType::class, $printing);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $modelFile = $form->get('filepath')->getData();
            if ($modelFile) {
                $modelFileName = $fileUploader->upload($modelFile);
                $printing->setFilepath($modelFileName);
            }
            $printing->setPurchase($purchase);
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($printing);
            $entityManager->flush();

            return $this->redirectToRoute('purchase_show', [
                'id' => $purchase->getId()
            ]);
        }

        return $this->render('printing/new.html.twig', [
            'printing' => $printing,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="printing_show", methods={"GET"})
     */
    public function show(Printing $printing): Response
    {
        return $this->render('printing/show.html.twig', [
            'printing' => $printing,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="printing_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, Printing $printing, FileUploader $fileUploader): Response
    {
        $form = $this->createForm(PrintingType::class, $printing);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $modelFile = $form->get('filepath')->getData();
            if ($modelFile) {
                $modelFileName = $fileUploader->upload($modelFile);
                $printing->setFilepath($modelFileName);
            }
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('purchase_index', [
                'id' => $printing->getPurchase()->getId()
            ]);
        }

        return $this->render('printing/edit.html.twig', [
            'printing' => $printing,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="printing_delete", methods={"POST"})
     */
    public function delete(Request $request, Printing $printing): Response
    {
        if ($this->isCsrfTokenValid('delete'.$printing->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($printing);
            $entityManager->flush();
        }

        return $this->redirectToRoute('purchase_show', [
            'id' => $printing->getPurchase()->getId()
        ]);
    }
}
