<?php

namespace App\Controller;

use App\Entity\Purchase;
use App\Form\PurchaseAddressType;
use App\Form\PurchaseType;
use App\Repository\PurchaseRepository;
use DateTimeImmutable;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/order")
 */
class PurchaseController extends AbstractController
{
    /**
     * @Route("/", name="purchase_index", methods={"GET"})
     */
    public function index(PurchaseRepository $purchaseRepository): Response
    {
        return $this->render('purchase/index.html.twig', [
            'purchases' => $purchaseRepository->findAll(),
        ]);
    }

    /**
     * @Route("/validate/{id}", name="purchase_validate", methods={"GET", "POST"})
     */
    public function validate(Purchase $purchase, Request $request): Response
    {
        $user = $this->getUser();
        if (!$purchase->getDeliveryName()) {
            $purchase->setDeliveryName($user->getFirstname() . ' ' . $user->getLastname());
        }
        if (!$purchase->getAddress()) {
            $purchase->setAddress($user->getAddress());
        }
        if (!$purchase->getZipcode()) {
            $purchase->setZipcode($user->getZipcode());
        }
        if (!$purchase->getCity()) {
            $purchase->setCity($user->getCity());
        }
        $form = $this->createForm(PurchaseAddressType::class, $purchase);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $purchase->setStatus("waiting_validation");
            $this->getDoctrine()->getManager()->flush();
            return $this->redirectToRoute('purchase_index');
        }

        return $this->render('purchase/validate.html.twig', [
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/new", name="purchase_new", methods={"GET","POST"})
     */
    public function new(): Response
    {
        $purchase = new Purchase();
        $purchase->setCreatedAt(new DateTimeImmutable());
        $purchase->setUser($this->getUser());
        $purchase->setReference(uniqid());

        $entityManager = $this->getDoctrine()->getManager();
        $entityManager->persist($purchase);
        $entityManager->flush();

        return $this->redirectToRoute('purchase_show', [
            'id' => $purchase->getId()
        ], Response::HTTP_SEE_OTHER);
    }

    /**
     * @Route("/{id}", name="purchase_show", methods={"GET"})
     */
    public function show(Purchase $purchase): Response
    {
        return $this->render('purchase/show.html.twig', [
            'purchase' => $purchase
        ]);
    }

    /**
     * @Route("/{id}", name="purchase_delete", methods={"POST"})
     */
    public function delete(Request $request, Purchase $purchase): Response
    {
        if ($this->isCsrfTokenValid('delete'.$purchase->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($purchase);
            $entityManager->flush();
        }

        return $this->redirectToRoute('purchase_index', [], Response::HTTP_SEE_OTHER);
    }
    
    /**
     * @Route("/{id}/cancel", name="purchase_cancel", methods={"GET"})
     */
    public function cancel(Purchase $purchase): Response
    {
        $entityManager = $this->getDoctrine()->getManager();
        $entityManager->remove($purchase);
        $entityManager->flush();

        return $this->redirectToRoute('purchase_index', [], Response::HTTP_SEE_OTHER);
    }
    
    /**
     * @Route("/{id}/revert", name="purchase_revert", methods={"GET"})
     */
    public function revert(Purchase $purchase): Response
    {
        $purchase->setStatus(null);
        $entityManager = $this->getDoctrine()->getManager();
        $entityManager->flush();

        return $this->redirectToRoute('purchase_index', [], Response::HTTP_SEE_OTHER);
    }
}
