<?php

namespace App\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ExceptionEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpFoundation\Session\SessionInterface;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use App\Exception\NotVerifiedUserException;

class ExceptionSubscriber implements EventSubscriberInterface
{
    /**
     * @var FlashBagInterface
     */
    private $flashBag;

    /**
     * @var UrlGeneratorInterface
     */
    private $router;

    public function __construct(SessionInterface $session, UrlGeneratorInterface $router) 
    {
        $this->flashBag = $session->getFlashBag();
        $this->router = $router;
    }

    public static function getSubscribedEvents()
    {
        // return the subscribed events, their methods and priorities
        return [
            KernelEvents::EXCEPTION => 'onException',
        ];
    }

    public function onException(ExceptionEvent $event)
    {
        // You get the exception object from the received event
        $exception = $event->getException();

        if (!$exception instanceof NotVerifiedUserException) {
            return;
        }

        $this->flashBag->add(
            'warning',
            $exception->getMessage()
        );

        $response = new RedirectResponse($this->router->generate('error'));
        $event->setResponse($response);     
    }
}