<?php

namespace App\Helper;

use App\Entity\Invoice;
use App\Entity\InvoiceLine;
use App\Entity\Purchase;
use DateTimeImmutable;

class InvoiceFactory {

    public static function create(?Purchase $purchase): Invoice
    {
        $invoice = new Invoice();
        $invoice->setReference(uniqid());
        if ($purchase) {
            foreach ($purchase->getPrintings() as $printing) {
                $line = new InvoiceLine();
                $line->setDescription("Impression #" . $printing->getId());
                $line->setQuantity($printing->getQuantity());
                $line->setPriceTtc(0.0);
                $invoice->addInvoiceLine($line);
            }
        }

        $line = new InvoiceLine();
        $line->setDescription("Frais de port");
        $line->setQuantity(1);
        $line->setPriceTtc(0.0);
        $invoice->addInvoiceLine($line);

        $line = new InvoiceLine();
        $line->setDescription("Remises et réductions");
        $line->setQuantity(1);
        $line->setPriceTtc(0.0);
        $invoice->addInvoiceLine($line);

        for ($i = 0; $i < 5; ++$i) {
            $invoice->addInvoiceLine(new InvoiceLine());
        }

        $invoice->setCreatedAt(new DateTimeImmutable());
        $invoice->setStatus('invoice_not_sent');
        if ($purchase) {
            $invoice->setPurchase($purchase);
        }
        return $invoice;
    }

}